';
-
- llxFooter();
- exit();
-}
-*/
-
-?>
+?>
\ No newline at end of file
diff --git a/htdocs/langs/el_GR/other.lang b/htdocs/langs/el_GR/other.lang
index b3c717c3550..1afefb9578e 100644
--- a/htdocs/langs/el_GR/other.lang
+++ b/htdocs/langs/el_GR/other.lang
@@ -109,7 +109,6 @@ ToExport=Export
NewExport=New export
##### External sites #####
ExternalSites=External sites
-FONTFORPDF=Freemono
// START - Lines generated via autotranslator.php tool (2011-06-26 15:35:22).
diff --git a/htdocs/langs/en_US/main.lang b/htdocs/langs/en_US/main.lang
index 64f8fbd44cf..8a297b6adce 100644
--- a/htdocs/langs/en_US/main.lang
+++ b/htdocs/langs/en_US/main.lang
@@ -19,7 +19,7 @@ FormatDateHourTextShort=%b %d, %Y, %I:%M %p
FormatDateHourText=%B %d, %Y, %I:%M %p
DatabaseConnection=Database connection
NoTranslation=No translation
-NoRecordFound=Aucun enregistrement trouvé
+NoRecordFound=No record found
NoError=No error
Error=Error
ErrorFieldRequired=Field '%s' is required
diff --git a/htdocs/langs/es_ES/products.lang b/htdocs/langs/es_ES/products.lang
index 66d64d3d4ff..fc9a1fb1d3c 100644
--- a/htdocs/langs/es_ES/products.lang
+++ b/htdocs/langs/es_ES/products.lang
@@ -84,14 +84,14 @@ ShowService=Mostrar servicio
ProductsAndServicesArea=Área productos y servicios
ProductsArea=Área Productos
ServicesArea=Área Servicios
-AddToMyProposals=Adjuntar a mis presupuestos
-AddToOtherProposals=Adjuntar a otros presupuestos
-AddToMyBills=Adjuntar a mis facturas
-AddToOtherBills=Adjuntar a otras facturas
+AddToMyProposals=Añadir a mis presupuestos
+AddToOtherProposals=Añadir a otros presupuestos
+AddToMyBills=Añadir a mis facturas
+AddToOtherBills=Añadir a otras facturas
CorrectStock=Corregir stock
AddPhoto=Adjuntar una foto
ListOfStockMovements=Listado de movimientos de stock
-NoPhotoYet=No hay fotografía disponible por el momento
+NoPhotoYet=No hay fotografías disponibles por el momento
BuyingPrice=Precio de compra
SupplierCard=Ficha proveedor
CommercialCard=Ficha comercial
@@ -114,6 +114,8 @@ AssociatedProductsAbility=Activar productos compuestos
AssociatedProducts=Productos compuestos
AssociatedProductsNumber=Nº de productos que componen este producto
ParentProductsNumber=Nº de productos que este producto compone
+IfZeroItIsNotAVirtualProduct=Si 0, este producto no es un producto virtual
+IfZeroItIsNotUsedByVirtualProduct=Si 0, este producto no está siendo utilizado por ningún producto virtual
EditAssociate=Componer
Translation=Traducción
KeywordFilter=Filtro por clave
diff --git a/htdocs/product/composition/fiche.php b/htdocs/product/composition/fiche.php
index 71ce35c76e1..644c321b8bb 100644
--- a/htdocs/product/composition/fiche.php
+++ b/htdocs/product/composition/fiche.php
@@ -72,7 +72,6 @@ $cancel <> $langs->trans("Cancel") &&
$error=0;
for($i=0;$i<$_POST["max_prod"];$i++)
{
- print " : ".$_POST["prod_id_chk".$i];
if ($_POST["prod_id_chk".$i] > 0)
{
if($product->add_sousproduit($id, $_POST["prod_id_".$i],$_POST["prod_qty_".$i]) > 0)
diff --git a/htdocs/product/fiche.php b/htdocs/product/fiche.php
index 0a8aed4634f..fa1f0fa5621 100644
--- a/htdocs/product/fiche.php
+++ b/htdocs/product/fiche.php
@@ -1417,7 +1417,7 @@ if ($object->id && ($action == '' || $action == 'view') && $object->status)
$langs->load("bills");
$html .= '
';
- $html .= '
'.$langs->trans("AddToOtherOrders").'
';
+ $html .= '
'.$langs->trans("AddToOtherBills").'
';
$html .= '
';
$html .= '
';
diff --git a/test/phpunit/NumberingModulesTest.php b/test/phpunit/NumberingModulesTest.php
index 5e93e32fe22..0700c784bae 100644
--- a/test/phpunit/NumberingModulesTest.php
+++ b/test/phpunit/NumberingModulesTest.php
@@ -212,9 +212,9 @@ class NumberingModulesTest extends PHPUnit_Framework_TestCase
$this->assertEquals(1, $result); // Case 1 can be deleted (because there was a reset for case 2)
// Try an offset when an invoice already exists
- $conf->global->FACTURE_MERCURE_MASK_CREDIT='{yyyy}{mm}-{0000+9990}';
- $conf->global->FACTURE_MERCURE_MASK_INVOICE='{yyyy}{mm}-{0000+9990}';
- $result=$numbering->getNextValue($mysoc, $localobject2);
+ $conf->global->FACTURE_MERCURE_MASK_CREDIT='{yyyy}{mm}-{0000+9990}';
+ $conf->global->FACTURE_MERCURE_MASK_INVOICE='{yyyy}{mm}-{0000+9990}';
+ $result=$numbering->getNextValue($mysoc, $localobject2);
// Now we try with a different fiscal month (forced by mask)
$conf->global->FACTURE_MERCURE_MASK_CREDIT='{yyyy}{mm}-{0000@6}';
diff --git a/test/phpunit/phpunittest.xml b/test/phpunit/phpunittest.xml
index 424359786ae..35083cb6d0f 100644
--- a/test/phpunit/phpunittest.xml
+++ b/test/phpunit/phpunittest.xml
@@ -47,6 +47,7 @@
../../htdocs/societe/canvas/../../htdocs/includes/../../htdocs/boutique/osc_master.inc.php
+ ../../htdocs/holiday/common.inc.php
diff --git a/htdocs/includes/tcpdf/tcpdf.php b/htdocs/includes/tcpdf/tcpdf.php
index a2fe57578e1..aee6fedeef3 100644
--- a/htdocs/includes/tcpdf/tcpdf.php
+++ b/htdocs/includes/tcpdf/tcpdf.php
@@ -76,7 +76,7 @@
// dullus for text Justification.
// Bob Vincent (pillarsdotnet@users.sourceforge.net) for
value attribute.
// Patrick Benny for text stretch suggestion on Cell().
-// Johannes Gntert for JavaScript support.
+// Johannes G�ntert for JavaScript support.
// Denis Van Nuffelen for Dynamic Form.
// Jacek Czekaj for multibyte justification
// Anthony Ferrara for the reintroduction of legacy image methods.
@@ -87,7 +87,7 @@
// Mohamad Ali Golkar, Saleh AlMatrafe, Charles Abbott for Arabic and Persian support.
// Moritz Wagner and Andreas Wurmser for graphic functions.
// Andrew Whitehead for core fonts support.
-// Esteban Jol Marn for OpenType font conversion.
+// Esteban Jo�l Mar�n for OpenType font conversion.
// Teus Hagen for several suggestions and fixes.
// Yukihiro Nakadaira for CID-0 CJK fonts fixes.
// Kosmas Papachristos for some CSS improvements.
@@ -5324,7 +5324,7 @@ class TCPDF {
$cbbox = array();
}
// initialize subsetchars
- $subsetchars = array();
+ $subsetchars = array_fill(0, 256, true);
$this->setFontBuffer($fontkey, array('fontkey' => $fontkey, 'i' => $this->numfonts, 'type' => $type, 'name' => $name, 'desc' => $desc, 'up' => $up, 'ut' => $ut, 'cw' => $cw, 'cbbox' => $cbbox, 'dw' => $dw, 'enc' => $enc, 'cidinfo' => $cidinfo, 'file' => $file, 'ctg' => $ctg, 'subset' => $subset, 'subsetchars' => $subsetchars));
if ($this->inxobj) {
// we are inside an XObject template
@@ -7123,7 +7123,7 @@ class TCPDF {
* @param $cellpadding (float) Internal cell padding, if empty uses default cell padding.
* @param $border (mixed) Indicates if borders must be drawn around the cell. The value can be a number:
0: no border (default)
1: frame
or a string containing some or all of the following characters (in any order):
L: left
T: top
R: right
B: bottom
or an array of line styles for each border group - for example: array('LTRB' => array('width' => 2, 'cap' => 'butt', 'join' => 'miter', 'dash' => 0, 'color' => array(0, 0, 0)))
* @return float Return the minimal height needed for multicell method for printing the $txt param.
- * @author Alexander Escalona Fernndez, Nicola Asuni
+ * @author Alexander Escalona Fern�ndez, Nicola Asuni
* @public
* @since 4.5.011
*/
@@ -7230,7 +7230,7 @@ class TCPDF {
* @param $cellpadding (float) Internal cell padding, if empty uses default cell padding.
* @param $border (mixed) Indicates if borders must be drawn around the cell. The value can be a number:
0: no border (default)
1: frame
or a string containing some or all of the following characters (in any order):
L: left
T: top
R: right
B: bottom
or an array of line styles for each border group - for example: array('LTRB' => array('width' => 2, 'cap' => 'butt', 'join' => 'miter', 'dash' => 0, 'color' => array(0, 0, 0)))
* @return float Return the minimal height needed for multicell method for printing the $txt param.
- * @author Nicola Asuni, Alexander Escalona Fernndez
+ * @author Nicola Asuni, Alexander Escalona Fern�ndez
* @public
*/
public function getStringHeight($w, $txt, $reseth=false, $autopadding=true, $cellpadding='', $border=0) {
@@ -15417,7 +15417,7 @@ class TCPDF {
}
/**
* Append a cubic Bzier curve to the current path. The curve shall extend from the current point to the point (x3, y3), using (x1, y1) and (x2, y2) as the Bzier control points.
* The new current point shall be (x3, y3).
* @param $x1 (float) Abscissa of control point 1.
* @param $y1 (float) Ordinate of control point 1.
@@ -15435,7 +15435,7 @@ class TCPDF {
}
/**
* Append a cubic Bzier curve to the current path. The curve shall extend from the current point to the point (x3, y3), using the current point and (x2, y2) as the Bzier control points.
* The new current point shall be (x3, y3).
* @param $x2 (float) Abscissa of control point 2.
* @param $y2 (float) Ordinate of control point 2.
@@ -15451,7 +15451,7 @@ class TCPDF {
}
/**
* Append a cubic Bzier curve to the current path. The curve shall extend from the current point to the point (x3, y3), using (x1, y1) and (x3, y3) as the Bzier control points.
* The new current point shall be (x3, y3).
* @param $x1 (float) Abscissa of control point 1.
* @param $y1 (float) Ordinate of control point 1.
@@ -16855,7 +16855,7 @@ class TCPDF {
/**
* Insert Named Destinations.
* @protected
- * @author Johannes Gntert, Nicola Asuni
+ * @author Johannes G�ntert, Nicola Asuni
* @since 5.9.098 (2011-06-23)
*/
protected function _putdests() {
@@ -17054,7 +17054,7 @@ class TCPDF {
* Adds a javascript
* @param $script (string) Javascript code
* @public
- * @author Johannes Gntert, Nicola Asuni
+ * @author Johannes G�ntert, Nicola Asuni
* @since 2.1.002 (2008-02-12)
*/
public function IncludeJS($script) {
@@ -17083,7 +17083,7 @@ class TCPDF {
/**
* Create a javascript PDF string.
* @protected
- * @author Johannes Gntert, Nicola Asuni
+ * @author Johannes G�ntert, Nicola Asuni
* @since 2.1.002 (2008-02-12)
*/
protected function _putjavascript() {
@@ -19146,7 +19146,7 @@ class TCPDF {
* @param $col1 (array) first color (Grayscale, RGB or CMYK components).
* @param $col2 (array) second color (Grayscale, RGB or CMYK components).
* @param $coords (array) array of the form (x1, y1, x2, y2) which defines the gradient vector (see linear_gradient_coords.jpg). The default value is from left to right (x1=0, y1=0, x2=1, y2=0).
- * @author Andreas Wrmser, Nicola Asuni
+ * @author Andreas W�rmser, Nicola Asuni
* @since 3.1.000 (2008-06-09)
* @public
*/
@@ -19164,7 +19164,7 @@ class TCPDF {
* @param $col1 (array) first color (Grayscale, RGB or CMYK components).
* @param $col2 (array) second color (Grayscale, RGB or CMYK components).
* @param $coords (array) array of the form (fx, fy, cx, cy, r) where (fx, fy) is the starting point of the gradient with color1, (cx, cy) is the center of the circle with color2, and r is the radius of the circle (see radial_gradient_coords.jpg). (fx, fy) should be inside the circle, otherwise some areas will not be defined.
- * @author Andreas Wrmser, Nicola Asuni
+ * @author Andreas W�rmser, Nicola Asuni
* @since 3.1.000 (2008-06-09)
* @public
*/
@@ -19187,7 +19187,7 @@ class TCPDF {
* @param $coords_min (array) minimum value used by the coordinates. If a coordinate's value is smaller than this it will be cut to coords_min. default: 0
* @param $coords_max (array) maximum value used by the coordinates. If a coordinate's value is greater than this it will be cut to coords_max. default: 1
* @param $antialias (boolean) A flag indicating whether to filter the shading function to prevent aliasing artifacts.
- * @author Andreas Wrmser, Nicola Asuni
+ * @author Andreas W�rmser, Nicola Asuni
* @since 3.1.000 (2008-06-09)
* @public
*/
@@ -19279,7 +19279,7 @@ class TCPDF {
* @param $y (float) ordinate of the top left corner of the rectangle.
* @param $w (float) width of the rectangle.
* @param $h (float) height of the rectangle.
- * @author Andreas Wrmser, Nicola Asuni
+ * @author Andreas W�rmser, Nicola Asuni
* @since 3.1.000 (2008-06-09)
* @protected
*/
@@ -20797,19 +20797,19 @@ class TCPDF {
// remove empty blocks
$cssdata = preg_replace('/([^\}\{]+)\{\}/', '', $cssdata);
// replace media type parenthesis
- $cssdata = preg_replace('/@media[\s]+([^\{]*)\{/i', '@media \\1', $cssdata);
- $cssdata = preg_replace('/\}\}/si', '}', $cssdata);
+ $cssdata = preg_replace('/@media[\s]+([^\{]*)\{/i', '@media \\1�', $cssdata);
+ $cssdata = preg_replace('/\}\}/si', '}�', $cssdata);
// trim string
$cssdata = trim($cssdata);
// find media blocks (all, braille, embossed, handheld, print, projection, screen, speech, tty, tv)
$cssblocks = array();
$matches = array();
- if (preg_match_all('/@media[\s]+([^\]*)([^]*)/i', $cssdata, $matches) > 0) {
+ if (preg_match_all('/@media[\s]+([^\�]*)�([^�]*)�/i', $cssdata, $matches) > 0) {
foreach ($matches[1] as $key => $type) {
$cssblocks[$type] = $matches[2][$key];
}
// remove media blocks
- $cssdata = preg_replace('/@media[\s]+([^\]*)([^]*)/i', '', $cssdata);
+ $cssdata = preg_replace('/@media[\s]+([^\�]*)�([^�]*)�/i', '', $cssdata);
}
// keep 'all' and 'print' media, other media types are discarded
if (isset($cssblocks['all']) AND !empty($cssblocks['all'])) {
@@ -29032,7 +29032,7 @@ Putting 1 is equivalent to putting 0 and calling Ln() just after. Default value:
}
break;
}
- case 'Q': { // quadratic Bzier curveto
+ case 'Q': { // quadratic B�zier curveto
foreach ($params as $ck => $cp) {
$params[$ck] = $cp;
if ((($ck + 1) % 4) == 0) {
@@ -29058,7 +29058,7 @@ Putting 1 is equivalent to putting 0 and calling Ln() just after. Default value:
}
break;
}
- case 'T': { // shorthand/smooth quadratic Bzier curveto
+ case 'T': { // shorthand/smooth quadratic B�zier curveto
foreach ($params as $ck => $cp) {
$params[$ck] = $cp;
if (($ck % 2) != 0) {
@@ -15417,7 +15417,7 @@ class TCPDF {
}
/**
- * Append a cubic Bzier curve to the current path. The curve shall extend from the current point to the point (x3, y3), using (x1, y1) and (x2, y2) as the Bzier control points.
+ * Append a cubic B�zier curve to the current path. The curve shall extend from the current point to the point (x3, y3), using (x1, y1) and (x2, y2) as the B�zier control points.
* The new current point shall be (x3, y3).
* @param $x1 (float) Abscissa of control point 1.
@@ -15435,7 +15435,7 @@ class TCPDF {
}
/**
- * Append a cubic Bzier curve to the current path. The curve shall extend from the current point to the point (x3, y3), using the current point and (x2, y2) as the Bzier control points.
+ * Append a cubic B�zier curve to the current path. The curve shall extend from the current point to the point (x3, y3), using the current point and (x2, y2) as the B�zier control points.
* The new current point shall be (x3, y3).
* @param $x2 (float) Abscissa of control point 2.
@@ -15451,7 +15451,7 @@ class TCPDF {
}
/**
- * Append a cubic Bzier curve to the current path. The curve shall extend from the current point to the point (x3, y3), using (x1, y1) and (x3, y3) as the Bzier control points.
+ * Append a cubic B�zier curve to the current path. The curve shall extend from the current point to the point (x3, y3), using (x1, y1) and (x3, y3) as the B�zier control points.
* The new current point shall be (x3, y3).
* @param $x1 (float) Abscissa of control point 1.